<?php

namespace Drupal\sharpspring;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Class SharpSpringSettings.
 *
 * @package Drupal\sharpspring
 */
class SharpSpringSettings implements SharpSpringSettingsInterface {

  const PAGES = "/admin\n/admin/*\n/batch\n/node/add*\n/node/*/*\n/user/*/*";

  /**
   * Module config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Settings array.
   *
   * @var array
   */
  protected $settings;

  /**
   * SharpSpringSettings constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory
  ) {
    $this->config = $configFactory->get('sharpspring.settings');
    $this->getSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function getSettings() {
    if (!$this->settings) {
      $settings = (array) $this->config->getOriginal();
      $settings += [
        'sharpspring_account' => 'KOI-',
        'sharpspring_domain' => 'koi-000000.sharpspring.com',
        'sharpspring_api_account_id' => NULL,
        'sharpspring_api_secret_key' => NULL,
        'visibility_pages' => 0,
        'pages' => static::PAGES,
        'visibility_roles' => 0,
        'roles' => [],
      ];

      $this->settings = $settings;
    }
    return $this->settings;
  }

  /**
   * {@inheritdoc}
   */
  public function getSetting($key, $default = NULL) {
    $this->getSettings();
    return array_key_exists($key, $this->settings) ? $this->settings[$key] : $default;
  }

}
